/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.tinydb;

import java.util.Collection;
import java.util.Map;

/**
 * DB相关的批量操作
 * 
 * @author luoguo
 * 
 */
interface DbOperatorBatch<BeanType, KeyType> {
	// 下面是根据数组
	int insert(BeanType[] beans);

	int update(BeanType[] beans);

	int delete(BeanType[] beans);

	int deleteById(KeyType[] beanIds);

	BeanType[] getBeans(KeyType[] beanIds);

	// 下面是根据集合
	int insert(Collection<BeanType> beans);

	int update(Collection<BeanType> beans);

	int delete(Collection<BeanType> beans);

	int deleteById(Collection<KeyType> beanIds);

	BeanType[] getBeans(Collection<KeyType> beanIds);

	// 下面是根据SQL
	BeanType[] getBeans(String sql);

	BeanType[] getBeans(String sql, int start, int limit);

	BeanType[] getBeans(String sql, Map<String, Object> parameters);

	BeanType[] getBeans(String sql, int start, int limit,
			Map<String, Object> parameters);

	BeanType[] getBeans(String sql, Object... parameters);

	BeanType[] getBeans(String sql, int start, int limit, Object... parameters);

	// 读取单一个值
	<T> T getSingleValue(String sql);

	<T> T getSingleValue(String sql, Map<String, Object> parameters);

	<T> T getSingleValue(String sql, Object... parameters);
}
